@@ -25,7 +25,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: bluetooth.h,v 1.13 2004/05/08 19:52:55 holtmann Exp $
+ *  $Id: bluetooth.h,v 1.17 2004/08/12 21:59:42 pkj Exp $
  */
 
 #ifndef __BLUETOOTH_H
@@ -52,6 +52,7 @@ extern "C" {
 #define BTPROTO_BNEP	4
 #define BTPROTO_CMTP	5
 #define BTPROTO_HIDP	6
+#define BTPROTO_AVDTP	7
 
 #define SOL_HCI		0
 #define SOL_L2CAP	6
@@ -87,15 +88,15 @@ enum {
 #endif
 
 /* Bluetooth unaligned access */
-#if defined(__i386__)
+#if defined(__i386__) || defined(__x86_64__) || defined(__powerpc__) || defined(__s390__) || defined(__cris__)
 #define bt_get_unaligned(ptr) (*(ptr))
 #define bt_put_unaligned(val, ptr) ((void)( *(ptr) = (val) ))
 #else
 #define bt_get_unaligned(ptr) \
-	({ __typeof__(*(ptr)) __tmp; memcpy(&__tmp, (ptr), sizeof(*(ptr))); __tmp; })
+	({ __typeof__(*(ptr)) __tmp; memmove(&__tmp, (ptr), sizeof(*(ptr))); __tmp; })
 #define bt_put_unaligned(val, ptr) \
 	({ __typeof__(*(ptr)) __tmp = (val); \
-	memcpy((ptr), &__tmp, sizeof(*(ptr))); \
+	memmove((ptr), &__tmp, sizeof(*(ptr))); \
 	(void)0; })
 #endif
 
