@@ -25,7 +25,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: hci.h,v 1.44 2004/11/09 22:52:40 holtmann Exp $
+ *  $Id: hci.h,v 1.46 2005/01/13 22:37:58 holtmann Exp $
  */
 
 #ifndef __HCI_H
@@ -677,6 +677,11 @@ typedef struct {
 	uint16_t	link_sup_to;
 } __attribute__ ((packed)) write_link_supervision_timeout_cp;
 #define WRITE_LINK_SUPERVISION_TIMEOUT_CP_SIZE 4
+typedef struct {
+	uint8_t		status;
+	uint16_t	handle;
+} __attribute__ ((packed)) write_link_supervision_timeout_rp;
+#define WRITE_LINK_SUPERVISION_TIMEOUT_RP_SIZE 3
 
 #define MAX_IAC_LAP 0x40
 #define OCF_READ_CURRENT_IAC_LAP	0x0039
@@ -791,13 +796,13 @@ typedef struct {
 } __attribute__ ((packed)) reset_failed_contact_counter_rp;
 #define RESET_FAILED_CONTACT_COUNTER_RP_SIZE 4
 
-#define OCF_GET_LINK_QUALITY		0x0003
+#define OCF_READ_LINK_QUALITY		0x0003
 typedef struct {
 	uint8_t		status;
 	uint16_t	handle;
 	uint8_t		link_quality;
-} __attribute__ ((packed)) get_link_quality_rp;
-#define GET_LINK_QUALITY_RP_SIZE 4
+} __attribute__ ((packed)) read_link_quality_rp;
+#define READ_LINK_QUALITY_RP_SIZE 4
 
 #define OCF_READ_RSSI			0x0005
 typedef struct {
