@@ -25,7 +25,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: hci_lib.h,v 1.32 2004/11/09 22:52:41 holtmann Exp $
+ *  $Id: hci_lib.h,v 1.37 2005/01/13 22:57:36 holtmann Exp $
  */
 
 #ifndef __HCI_LIB_H
@@ -66,11 +66,8 @@ int hci_devinfo(int dev_id, struct hci_dev_info *di);
 int hci_devba(int dev_id, bdaddr_t *bdaddr);
 int hci_devid(const char *str);
 
-/* deprecated: preserve compatibility */
-int hci_local_name(int dd, int len, char *name, int to);
 int hci_read_local_name(int dd, int len, char *name, int to);
 int hci_write_local_name(int dd, const char *name, int to);
-int hci_remote_name(int dd, const bdaddr_t *bdaddr, int len, char *name, int to);
 int hci_read_remote_name(int dd, const bdaddr_t *bdaddr, int len, char *name, int to);
 int hci_read_remote_features(int dd, uint16_t handle, uint8_t *features, int to);
 int hci_read_remote_version(int dd, uint16_t handle, struct hci_version *ver, int to);
@@ -85,7 +82,6 @@ int hci_write_current_iac_lap(int dd, uint8_t num_iac, uint8_t *lap, int to);
 int hci_authenticate_link(int dd, uint16_t handle, int to);
 int hci_encrypt_link(int dd, uint16_t handle, uint8_t encrypt, int to);
 int hci_change_link_key(int dd, uint16_t handle, int to);
-/* role == 0 is master, 1 is slave */
 int hci_switch_role(int dd, bdaddr_t *bdaddr, uint8_t role, int to);
 int hci_park_mode(int dd, uint16_t handle, uint16_t max_interval, uint16_t min_interval, int to);
 int hci_exit_park_mode(int dd, uint16_t handle, int to);
@@ -93,7 +89,12 @@ int hci_read_inquiry_mode(int dd, uint8_t *mode, int to);
 int hci_write_inquiry_mode(int dd, uint8_t mode, int to);
 int hci_read_afh_mode(int dd, uint8_t *mode, int to);
 int hci_write_afh_mode(int dd, uint8_t mode, int to);
+int hci_read_transmit_power_level(int dd, uint16_t handle, uint8_t type, uint8_t *level, int to);
+int hci_read_link_supervision_timeout(int dd, uint16_t handle, uint16_t *timeout, int to);
+int hci_write_link_supervision_timeout(int dd, uint16_t handle, uint16_t timeout, int to);
 int hci_set_afh_classification(int dd, uint8_t *map, int to);
+int hci_read_link_quality(int dd, uint16_t handle, uint8_t *link_quality, int to);
+int hci_read_rssi(int dd, uint16_t handle, int8_t *rssi, int to);
 int hci_read_afh_map(int dd, uint16_t handle, uint8_t *mode, uint8_t *map, int to);
 
 int hci_for_each_dev(int flag, int(*func)(int s, int dev_id, long arg), long arg);
@@ -102,18 +103,18 @@ int hci_get_route(bdaddr_t *bdaddr);
 char *hci_dtypetostr(int type);
 char *hci_dflagstostr(uint32_t flags);
 char *hci_ptypetostr(unsigned int ptype);
-int   hci_strtoptype(char *str, unsigned int *val);
+int hci_strtoptype(char *str, unsigned int *val);
 char *hci_scoptypetostr(unsigned int ptype);
-int   hci_strtoscoptype(char *str, unsigned int *val);
+int hci_strtoscoptype(char *str, unsigned int *val);
 char *hci_lptostr(unsigned int ptype);
-int   hci_strtolp(char *str, unsigned int *val);
+int hci_strtolp(char *str, unsigned int *val);
 char *hci_lmtostr(unsigned int ptype);
-int   hci_strtolm(char *str, unsigned int *val);
+int hci_strtolm(char *str, unsigned int *val);
 
 char *hci_vertostr(unsigned int ver);
-int   hci_strtover(char *str, unsigned int *ver);
+int hci_strtover(char *str, unsigned int *ver);
 char *lmp_vertostr(unsigned int ver);
-int   lmp_strtover(char *str, unsigned int *ver);
+int lmp_strtover(char *str, unsigned int *ver);
 
 char *lmp_featurestostr(uint8_t *features, char *pref, int width);
 
