@@ -24,7 +24,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: rfcomm.h,v 1.12 2004/11/09 12:46:35 holtmann Exp $
+ *  $Id: rfcomm.h,v 1.13 2004/12/25 17:35:34 holtmann Exp $
  */
 
 #ifndef __RFCOMM_H
@@ -50,6 +50,12 @@ struct sockaddr_rc {
 };
 
 /* RFCOMM socket options */
+#define RFCOMM_CONNINFO	0x02
+struct rfcomm_conninfo {
+	uint16_t	hci_handle;
+	uint8_t		dev_class[3];
+};
+
 #define RFCOMM_LM	0x03
 #define RFCOMM_LM_MASTER	0x0001
 #define RFCOMM_LM_AUTH		0x0002
