@@ -25,7 +25,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: hci.c,v 1.52 2004/11/09 22:52:42 holtmann Exp $
+ *  $Id: hci.c,v 1.57 2005/01/13 22:57:37 holtmann Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -55,7 +55,8 @@
 #include <bluetooth/hci_lib.h>
 
 typedef struct {
-	char  *str; unsigned int val;
+	char *str;
+	unsigned int val;
 } hci_map;
 
 static char *hci_bit2str(hci_map *m, unsigned int val) 
@@ -255,11 +256,11 @@ int hci_strtoscoptype(char *str, unsigned int *val)
 
 /* Link policy mapping */
 static hci_map link_policy_map[] = {
-	{ "NONE",    0 },
-	{ "RSWITCH", HCI_LP_RSWITCH },
-	{ "HOLD",    HCI_LP_HOLD    },
-	{ "SNIFF",   HCI_LP_SNIFF   },
-	{ "PARK",    HCI_LP_PARK    },
+	{ "NONE",	0		},
+	{ "RSWITCH",	HCI_LP_RSWITCH	},
+	{ "HOLD",	HCI_LP_HOLD	},
+	{ "SNIFF",	HCI_LP_SNIFF	},
+	{ "PARK",	HCI_LP_PARK	},
 	{ NULL }
 };
 
@@ -275,12 +276,14 @@ int hci_strtolp(char *str, unsigned int *val)
 
 /* Link mode mapping */
 static hci_map link_mode_map[] = {
-	{ "NONE",    0 },
-	{ "ACCEPT",  HCI_LM_ACCEPT },
-	{ "MASTER",  HCI_LM_MASTER },
-	{ "AUTH",    HCI_LM_AUTH   },
-	{ "ENCRYPT", HCI_LM_ENCRYPT},
-	{ "TRUSTED", HCI_LM_TRUSTED},
+	{ "NONE",	0		},
+	{ "ACCEPT",	HCI_LM_ACCEPT	},
+	{ "MASTER",	HCI_LM_MASTER	},
+	{ "AUTH",	HCI_LM_AUTH	},
+	{ "ENCRYPT",	HCI_LM_ENCRYPT	},
+	{ "TRUSTED",	HCI_LM_TRUSTED	},
+	{ "RELIABLE",	HCI_LM_RELIABLE	},
+	{ "SECURE",	HCI_LM_SECURE	},
 	{ NULL }
 };
 
@@ -847,11 +850,6 @@ int hci_disconnect(int dd, uint16_t handle, uint8_t reason, int to)
 	return 0;
 }
 
-int hci_local_name(int dd, int len, char *name, int to)
-{
-	return hci_read_local_name(dd, len, name, to);
-}
-
 int hci_read_local_name(int dd, int len, char *name, int to)
 {
 	read_local_name_rp rp;
@@ -893,11 +891,6 @@ int hci_write_local_name(int dd, const char *name, int to)
 	return 0;
 }
 
-int hci_remote_name(int dd, const bdaddr_t *bdaddr, int len, char *name, int to)
-{
-	return hci_read_remote_name(dd, bdaddr, len, name, to);
-}
-
 int hci_read_remote_name(int dd, const bdaddr_t *bdaddr, int len, char *name, int to)
 {
 	evt_remote_name_req_complete rn;
@@ -1439,6 +1432,90 @@ int hci_write_afh_mode(int dd, uint8_t mode, int to)
 	return 0;
 }
 
+int hci_read_transmit_power_level(int dd, uint16_t handle, uint8_t type, uint8_t *level, int to)
+{
+	read_transmit_power_level_cp cp;
+	read_transmit_power_level_rp rp;
+	struct hci_request rq;
+
+	memset(&cp, 0, sizeof(cp));
+	cp.handle = handle;
+	cp.type   = type;
+
+	memset(&rq, 0, sizeof(rq));
+	rq.ogf    = OGF_HOST_CTL;
+	rq.ocf    = OCF_READ_TRANSMIT_POWER_LEVEL;
+	rq.cparam = &cp;
+	rq.clen   = READ_TRANSMIT_POWER_LEVEL_CP_SIZE;
+	rq.rparam = &rp;
+	rq.rlen   = READ_TRANSMIT_POWER_LEVEL_RP_SIZE;
+
+	if (hci_send_req(dd, &rq, to) < 0)
+		return -1;
+
+	if (rp.status) {
+		errno = EIO;
+		return -1;
+	}
+
+	*level = rp.level;
+	return 0;
+}
+
+int hci_read_link_supervision_timeout(int dd, uint16_t handle, uint16_t *timeout, int to)
+{
+	read_link_supervision_timeout_rp rp;
+	struct hci_request rq;
+
+	memset(&rq, 0, sizeof(rq));
+	rq.ogf    = OGF_HOST_CTL;
+	rq.ocf    = OCF_READ_LINK_SUPERVISION_TIMEOUT;
+	rq.cparam = &handle;
+	rq.clen   = 2;
+	rq.rparam = &rp;
+	rq.rlen   = READ_LINK_SUPERVISION_TIMEOUT_RP_SIZE;
+
+	if (hci_send_req(dd, &rq, to) < 0)
+		return -1;
+
+	if (rp.status) {
+		errno = EIO;
+		return -1;
+	}
+
+	*timeout = rp.link_sup_to;
+	return 0;
+}
+
+int hci_write_link_supervision_timeout(int dd, uint16_t handle, uint16_t timeout, int to)
+{
+	write_link_supervision_timeout_cp cp;
+	write_link_supervision_timeout_rp rp;
+	struct hci_request rq;
+
+	memset(&cp, 0, sizeof(cp));
+	cp.handle      = handle;
+	cp.link_sup_to = timeout;
+
+	memset(&rq, 0, sizeof(rq));
+	rq.ogf    = OGF_HOST_CTL;
+	rq.ocf    = OCF_WRITE_LINK_SUPERVISION_TIMEOUT;
+	rq.cparam = &cp;
+	rq.clen   = WRITE_LINK_SUPERVISION_TIMEOUT_CP_SIZE;
+	rq.rparam = &rp;
+	rq.rlen   = WRITE_LINK_SUPERVISION_TIMEOUT_RP_SIZE;
+
+	if (hci_send_req(dd, &rq, to) < 0)
+		return -1;
+
+	if (rp.status) {
+		errno = EIO;
+		return -1;
+	}
+
+	return 0;
+}
+
 int hci_set_afh_classification(int dd, uint8_t *map, int to)
 {
 	set_afh_classification_cp cp;
@@ -1467,6 +1544,56 @@ int hci_set_afh_classification(int dd, uint8_t *map, int to)
 	return 0;
 }
 
+int hci_read_link_quality(int dd, uint16_t handle, uint8_t *link_quality, int to)
+{
+	read_link_quality_rp rp;
+	struct hci_request rq;
+
+	memset(&rq, 0, sizeof(rq));
+	rq.ogf    = OGF_STATUS_PARAM;
+	rq.ocf    = OCF_READ_LINK_QUALITY;
+	rq.cparam = &handle;
+	rq.clen   = 2;
+	rq.rparam = &rp;
+	rq.rlen   = READ_LINK_QUALITY_RP_SIZE;
+
+	if (hci_send_req(dd, &rq, to) < 0)
+		return -1;
+
+	if (rp.status) {
+		errno = EIO;
+		return -1;
+	}
+
+	*link_quality = rp.link_quality;
+	return 0;
+}
+
+int hci_read_rssi(int dd, uint16_t handle, int8_t *rssi, int to)
+{
+	read_rssi_rp rp;
+	struct hci_request rq;
+
+	memset(&rq, 0, sizeof(rq));
+	rq.ogf    = OGF_STATUS_PARAM;
+	rq.ocf    = OCF_READ_RSSI;
+	rq.cparam = &handle;
+	rq.clen   = 2;
+	rq.rparam = &rp;
+	rq.rlen   = READ_RSSI_RP_SIZE;
+
+	if (hci_send_req(dd, &rq, to) < 0)
+		return -1;
+
+	if (rp.status) {
+		errno = EIO;
+		return -1;
+	}
+
+	*rssi = rp.rssi;
+	return 0;
+}
+
 int hci_read_afh_map(int dd, uint16_t handle, uint8_t *mode, uint8_t *map, int to)
 {
 	read_afh_map_rp rp;
